@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::Author::OpusVL;
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
  
 use Dist::Zilla::PluginBundle::Basic;
 use Dist::Zilla::PluginBundle::Filter;
@@ -38,6 +38,7 @@ sub configure {
         RewriteVersion
         NextRelease
         Repository
+        PodWeaver
     ),
         [ 'Git::Commit' =>
             CommitGeneratedFiles => { 
@@ -104,6 +105,7 @@ It is roughly equivalent to:
   [RewriteVersion]
   [NextRelease]
   [Repository]
+  [PodWeaver]
   
   [Git::Commit / CommitGeneratedFiles]
   allow_dirty = dist.ini
